# Deceptive Marketing Classification

[![pypi-image]][pypi-url]
[![version-image]][release-url]
[![release-date-image]][release-url]
[![license-image]][license-url]
[![codecov][codecov-image]][codecov-url]
[![jupyter-book-image]][docs-url]

<!-- Links: -->
[codecov-image]: https://codecov.io/gh/entelecheia/demarc/branch/main/graph/badge.svg?token=44aJmHU2rm
[codecov-url]: https://codecov.io/gh/entelecheia/demarc
[pypi-image]: https://img.shields.io/pypi/v/demarc
[license-image]: https://img.shields.io/github/license/entelecheia/demarc
[license-url]: https://github.com/entelecheia/demarc/blob/main/LICENSE
[version-image]: https://img.shields.io/github/v/release/entelecheia/demarc?sort=semver
[release-date-image]: https://img.shields.io/github/release-date/entelecheia/demarc
[release-url]: https://github.com/entelecheia/demarc/releases
[jupyter-book-image]: https://jupyterbook.org/en/stable/_images/badge.svg

[repo-url]: https://github.com/entelecheia/demarc
[pypi-url]: https://pypi.org/project/demarc
[docs-url]: https://demarc.entelecheia.ai
[changelog]: https://github.com/entelecheia/demarc/blob/main/CHANGELOG.md
[contributing guidelines]: https://github.com/entelecheia/demarc/blob/main/CONTRIBUTING.md
<!-- Links: -->

A Python package for Deceptive Marketing Classification.

- Documentation: [https://demarc.entelecheia.ai][docs-url]
- GitHub: [https://github.com/entelecheia/demarc][repo-url]
- PyPI: [https://pypi.org/project/demarc][pypi-url]

This study aims to compare and analyze Naver Map reviews of restaurants that closed within a short period and those that achieved long-term success, in order to identify the characteristics of fake promotional reviews and develop a methodology for detecting them. We will apply Natural Language Processing (NLP) techniques using Large Language Models (LLMs) and representation vectors, and conduct an integrated analysis with rental car stay point data to investigate the relationship with actual business performance.

## Changelog

See the [CHANGELOG] for more information.

## Contributing

Contributions are welcome! Please see the [contributing guidelines] for more information.

## License

This project is released under the [MIT License][license-url].
